.. url = /
.. title = django-fileflatpages
.. template_name = flatpages/rst.html

=======
 Index
=======

This is a example_project showing of django-fileflatpages. This file is a
FlatPage that was rendered from ReST_. The rst file is at
example_project/app/flatpages/index.rst and was inserted into the database
with the command **loadflatpages**.

Visit the About_ page for another ReST file, or visit Test_ for a page
rendered from HTML.

.. _ReST: http://docutils.sourceforge.net/
.. _About: /about/
.. _Test: /test/
